==> ejc-budgetmanage-impl-3.0.0-20220330.112743-39-sources.jar: com/ejianc/business/record/vo/RecordsubpackagematerialanalysisVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包施工图预算材料分析变更记录
 * 
 * @author generator
 * 
 */
public class RecordsubpackagematerialanalysisVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long originalId; // 原始单据id
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.String changeState; // 变更状态
    private java.lang.String changeReason; // 变更原因
    private java.util.Date effectDate; // 生效时间
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.String subpackagematerialanalysisCode; // 变更单据


    private List<RecordsubpackmateanalydetailVO> subpackagematerialanalysisdetailEntites = new ArrayList<>(); // 分包施工图预算材料分析变更记录子表

        /**
         * 单据编号
         */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更状态
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包施工图预算材料分析变更记录子表
     */
    public List<RecordsubpackmateanalydetailVO> getSubpackagematerialanalysisdetailEntites() {
        return subpackagematerialanalysisdetailEntites;
    }

    /**
     * 分包施工图预算材料分析变更记录子表
     */
    public void setSubpackagematerialanalysisdetailEntites(List<RecordsubpackmateanalydetailVO> subpackagematerialanalysisdetailEntites) {
        this.subpackagematerialanalysisdetailEntites = subpackagematerialanalysisdetailEntites;
    }




    public String getSubpackagematerialanalysisCode() {
        return subpackagematerialanalysisCode;
    }

    public void setSubpackagematerialanalysisCode(String subpackagematerialanalysisCode) {
        this.subpackagematerialanalysisCode = subpackagematerialanalysisCode;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20220404.033202-49-sources.jar: com/ejianc/business/record/vo/RecordsubpackagematerialanalysisVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包施工图预算材料分析变更记录
 * 
 * @author generator
 * 
 */
public class RecordsubpackagematerialanalysisVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long originalId; // 原始单据id
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.String changeState; // 变更状态
    private java.lang.String changeReason; // 变更原因
    private java.util.Date effectDate; // 生效时间
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.String subpackagematerialanalysisCode; // 变更单据
    private java.lang.Double total;//合计汇总数量


    private List<RecordsubpackmateanalydetailVO> subpackagematerialanalysisdetailEntites = new ArrayList<>(); // 分包施工图预算材料分析变更记录子表

        /**
         * 单据编号
         */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 原始单据id
     */
    public java.lang.Long getOriginalId() {
        return originalId;
    }

    /**
     * 原始单据id
     */
    public void setOriginalId(java.lang.Long originalId) {
        this.originalId = originalId;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更状态
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 分包施工图预算材料分析变更记录子表
     */
    public List<RecordsubpackmateanalydetailVO> getSubpackagematerialanalysisdetailEntites() {
        return subpackagematerialanalysisdetailEntites;
    }

    /**
     * 分包施工图预算材料分析变更记录子表
     */
    public void setSubpackagematerialanalysisdetailEntites(List<RecordsubpackmateanalydetailVO> subpackagematerialanalysisdetailEntites) {
        this.subpackagematerialanalysisdetailEntites = subpackagematerialanalysisdetailEntites;
    }




    public String getSubpackagematerialanalysisCode() {
        return subpackagematerialanalysisCode;
    }

    public void setSubpackagematerialanalysisCode(String subpackagematerialanalysisCode) {
        this.subpackagematerialanalysisCode = subpackagematerialanalysisCode;
    }

    public Double getTotal() {
        return total;
    }

    public void setTotal(Double total) {
        this.total = total;
    }
}
